### soothsayer_utils
Utility functions for **[Soothsayer](http://www.github.com/jolespin/soothsayer)**

#### Dependencies:
Compatible for Python 2 and 3.

```
# Required:
pandas
numpy
tqdm
tzlocal
requests # Python 2/3 compatibility
pathlib2 # Python 2/3 compatibility	
bz2file # Python 2/3 compatibility

# Optional:
biopython
mmh3
matplotlib
```
#### Install
```
# "Stable" release (still developmental)
pip install soothsayer-utils
# Current release
pip install git+https://github.com/jolespin/soothsayer_utils
```